@@ -81,13 +81,7 @@ def _set_remote_endpoint(span: SpanAbc, request: Request) -> None:
 
 
 def _get_span(request: Request, tracer: Tracer) -> SpanAbc:
-    # builds span from incoming request, if no context found, create
-    # new span
-    context = tracer.make_context(request.headers)
-
-    if context is None:
-        return tracer.new_trace()
-    return tracer.join_span(context)
+    return tracer.get_span(request.headers)
 
 
 def _set_span_properties(span: SpanAbc, request: Request) -> None:
